@@ -1,8 +1,8 @@
 """
 This module gives an example of how to run the main ELM class.
 
-It uses the hydra library to load the config from the
-config/elm_sodarace_cfg.yaml file.
+It uses the hydra library to load the config from the config dataclasses in
+configs.py.
 
 This config file demonstrates an example of running ELM with the Sodarace
 environment, a 2D physics-based environment in which robots specified by
@@ -13,19 +13,20 @@ import hydra
 from omegaconf import OmegaConf
 
 from openelm import ELM
-from openelm.constants import SRC_PATH
 
 
-# Load hydra config from yaml files and command line arguments.
 @hydra.main(
-    config_path=str(SRC_PATH / "config"), config_name="elm_sodarace_cfg", version_base="1.2"
+    config_name="elmconfig",
+    version_base="1.2",
 )
-def main(cfg):
+def main(config):
     print("----------------- Config ---------------")
-    print(OmegaConf.to_yaml(cfg))
+    print(OmegaConf.to_yaml(config))
     print("-----------------  End -----------------")
-    elm = ELM(cfg)
-    print("Best Sodaracer: ", elm.run())
+    config = OmegaConf.to_object(config)
+    elm = ELM(config)
+    print("Best Individual: ", elm.run(init_steps=config.qd.init_steps,
+                                       total_steps=config.qd.total_steps))
 
 
 if __name__ == "__main__":
