@@ -1,6 +1,6 @@
 import math
 
-from openelm.sandbox.server.environments.walker.walk_creator import walker_creator
+from .walk_creator import walker_creator
 
 
 def make_circle(wc, cx, cy, radius, num_points):
